Deployment guide — Kedro 0.17.6 documentation

# Deployment guide

## Deployment choices

Your choice of deployment method will depend on a number of factors. In this section we provide a number of guides for different approaches.

If you decide to deploy your Kedro project on a single machine, you should consult our guide to single-machine deployment, and decide whether to use Docker for container-based deployment or to use package-based deployment or to use the CLI to clone and deploy your codebase to a server.

If your pipeline is sizeable, you will want to run parts of it on separate machines, so will need to consult our guide to distributed deployment.

We also provide information to help you deploy to the following:

- to Argo Workflows

- to Prefect

- to Kubeflow Workflows

- to AWS Batch

- to Databricks

In addition, we also provide instructions on how to integrate a Kedro project with Amazon SageMaker.